@@ -23,7 +23,26 @@ def get_mrn(pmi) -> str:
     return pmi["MRN"] if pmi.get("MRN") else ""
 
 
+def get_trf(sample) -> str:
+    return sample["TRFNumber"] if sample.get("TRFNumber") else ""
+
+
+def get_med_facil(pmi) -> list:
+    med_facil_info = []
+    med_facil_info.append(pmi["MedFacilName"] if pmi.get("MedFacilName") else "")
+    med_facil_info.append(pmi["MedFacilID"] if pmi.get("MedFacilID") else "")
+    return med_facil_info
+
+
+def get_ordering_md(pmi, npi) -> list:
+    ordering_md_info = []
+    ordering_md_info.append(pmi["OrderingMD"] if pmi.get("OrderingMD") else "")
+    ordering_md_info.append(npi)
+    return ordering_md_info
+
+
 def get_test_yml(
+    customer_info_dict: dict,
     results_payload_dict: dict,
     base_xml_name: str,
     local_output_dir: str,
@@ -31,10 +50,13 @@ def get_test_yml(
     write_vcf_to_manifest: bool,
     phc_output_dir: str,
 ) -> dict:
+    npi = customer_info_dict.get("rr:NPI", {})
     pmi = results_payload_dict.get("FinalReport", {}).get("PMI", {})
+    signatures = results_payload_dict.get("FinalReport", {}).get("Signatures")
     sample = results_payload_dict.get("FinalReport", {}).get("Sample", {})
     variant_report = results_payload_dict.get("variant-report", {})
     biomarkers = variant_report.get("biomarkers", {})
+    non_human_content = variant_report.get("non-human-content", {})
     report_properties = results_payload_dict.get("FinalReport", {}).get("reportProperties", {})
     report_property = report_properties.get("reportProperty", [])
     genes = results_payload_dict.get("FinalReport", {}).get("Genes", [])
@@ -48,8 +70,22 @@ def get_test_yml(
 
     mrn = get_mrn(pmi)
 
+    trf = get_trf(sample)
+
+    med_facil_info = get_med_facil(pmi)
+
+    ordering_md_info = get_ordering_md(pmi, npi)
+
     # fallback on previous behavior for indexedDate if value is not found
     indexedDate = get_date(pmi.get("CollDate")) or get_date(sample.get("ReceivedDate"))
+
+    # store both values sperately
+    receivedDate = get_date(sample.get("ReceivedDate"))
+    collDate = get_date(pmi.get("CollDate"))
+
+    # store date of published report
+    reportDate = str(get_date(signatures.get("Signature").get("ServerTime")))[0:10]
+
     yaml_file = {
         "tests": [
             {
@@ -58,9 +94,17 @@ def get_test_yml(
                 "sourceFile": f"{base_xml_name}.xml",
                 "testType": sample.get("TestType"),
                 "indexedDate": indexedDate,
+                "receivedDate": receivedDate,
+                "collDate": collDate,
+                "reportDate": reportDate,
+                "reportID": trf,
                 "mrn": mrn,
                 "patientDOB": get_date(pmi.get("DOB")),
                 "patientLastName": pmi.get("LastName"),
+                "medFacilName": med_facil_info[0],
+                "medFacilID": med_facil_info[1],
+                "orderingMDName": ordering_md_info[0],
+                "orderingMDNPI": ordering_md_info[1],
                 "bodySite": variant_report.get("@tissue-of-origin"),
                 "bodySiteSystem": "http://foundation.com/bodySite",
                 "bodySiteDisplay": variant_report.get("@tissue-of-origin"),
@@ -145,6 +189,28 @@ def get_test_yml(
         yaml_file["tests"][0]["tmb"] = tumor_dict.get("@status", "unknown")
         yaml_file["tests"][0]["tmbScore"] = float(tumor_dict.get("@score"))
 
+    # adding non-human content fields
+    if non_human_content and "non-human" in non_human_content:
+        nhc_dict = non_human_content["non-human"]
+        # if there are multiple instances of non-human content fields, get lists for each subfield
+        if isinstance(nhc_dict, list):
+            nhcOrganism_list = []
+            nhcReadsPerMil_list = []
+            nhcStatus_list = []
+            for dictionary in nhc_dict:
+                nhcOrganism_list.append(dictionary.get("@organism", "unknown"))
+                nhcReadsPerMil_list.append(float(dictionary.get("@reads-per-million")))
+                nhcStatus_list.append(dictionary.get("@status", "unknown"))
+
+            yaml_file["tests"][0]["nhcOrganism"] = nhcOrganism_list
+            yaml_file["tests"][0]["nhcReadsPerMil"] = nhcReadsPerMil_list
+            yaml_file["tests"][0]["nhcStatus"] = nhcStatus_list
+
+        else:
+            yaml_file["tests"][0]["nhcOrganism"] = nhc_dict.get("@organism", "unknown")
+            yaml_file["tests"][0]["nhcReadsPerMil"] = float(nhc_dict.get("@reads-per-million"))
+            yaml_file["tests"][0]["nhcStatus"] = nhc_dict.get("@status", "unknown")
+
     if report_file:
         copyfile(report_file, f"{local_output_dir}/{base_xml_name}/{base_xml_name}.report.pdf")
 
