@@ -1,11 +1,18 @@
 import gzip
+import csv
 import os
 import shutil
 import xmltodict
 
 from ingestion.foundation.util.cnv import extract_copy_numbers
 from ingestion.foundation.util.fnv import extract_fusion_variant
-from ingestion.foundation.util.ga4gh import get_test_yml, get_mrn
+from ingestion.foundation.util.ga4gh import (
+    get_med_facil,
+    get_ordering_md,
+    get_test_yml,
+    get_mrn,
+    get_trf,
+)
 from ingestion.foundation.util.vcf_etl import vcf_etl, transform_scientific_notation_in_af
 
 BASE_PATH = os.path.abspath(os.path.dirname(__file__))
@@ -74,16 +81,29 @@ def test_fnv():
         mock_log,
     )
 
-    csv = open(f"{BASE_PATH}/data/sample/sample.structural.csv")
-    text = csv.read()
-    csv.close()
-
-    assert (
-        text
-        == """sample_id,gene1,gene2,effect,chromosome1,start_position1,end_position1,chromosome2,start_position2,end_position2,interpretation,sequence_type,in-frame,attributes
-SA-1612348,NF1,N/A,truncation,chr17,29557687,29887856,chr6,66426718,66427149,Likely pathogenic,somatic,unknown,"{'equivocal': 'false', 'supporting-read-pairs': '83'}"
-"""
-    )
+    with open(f"{BASE_PATH}/data/sample/sample.structural.csv", newline="") as test_in:
+        csv_reader = csv.reader(test_in)
+        test_data = list(csv_reader)
+        # Check header is correct
+        assert (
+            ",".join(test_data[0])
+            == "sample_id,gene1,gene2,effect,chromosome1,start_position1,end_position1,chromosome2,start_position2,end_position2,interpretation,sequence_type,in-frame,attributes"
+        )
+        # Check when both chromosomes are given ranges
+        assert (
+            ",".join(test_data[1])
+            == "SA-1612348,NF1,N/A,truncation,chr17,29557687,29887856,chr6,66426718,66427149,Likely pathogenic,somatic,unknown,{'equivocal': 'false', 'supporting-read-pairs': '83'}"
+        )
+        # Check when single loci, different chromosomes
+        assert (
+            ",".join(test_data[2])
+            == "SA-1612348,NF1,FN2,fusion,chr17,29557687,29557687,chr6,66426718,66426718,Likely pathogenic,somatic,unknown,{'equivocal': 'false', 'supporting-read-pairs': '83'}"
+        )
+        # Check when single loci, same chromosome
+        assert (
+            ",".join(test_data[3])
+            == "SA-1612348,FN2,NF1,rearrangement,chr17,29557687,29557687,chr17,29557790,29557790,Likely pathogenic,somatic,unknown,{'equivocal': 'false', 'supporting-read-pairs': '83'}"
+        )
 
 
 def test_yml():
@@ -93,6 +113,7 @@ def test_yml():
     xml = read_xml(f"{BASE_PATH}/data/sample.xml")
 
     yml = get_test_yml(
+        xml["rr:ResultsReport"]["rr:CustomerInformation"],
         xml["rr:ResultsReport"]["rr:ResultsPayload"],
         "SA-1612348",
         f"{BASE_PATH}/data",
@@ -109,9 +130,17 @@ def test_yml():
                 "sourceFile": "SA-1612348.xml",
                 "testType": "FoundationOne Heme",
                 "indexedDate": "2016-07-15",
+                "receivedDate": "2016-07-21",
+                "collDate": "2016-07-15",
+                "reportDate": "2016-08-25",
                 "mrn": "12345678",
+                "reportID": "SMP37669",
                 "patientDOB": "2002-12-12",
                 "patientLastName": "Patient",
+                "medFacilName": "ABC Oncology",
+                "medFacilID": "200313",
+                "orderingMDName": "Smith, John",
+                "orderingMDNPI": "1508888051",
                 "bodySite": "Bone",
                 "bodySiteSystem": "http://foundation.com/bodySite",
                 "bodySiteDisplay": "Bone",
@@ -153,6 +182,9 @@ def test_yml():
                 "msi": "stable",
                 "tmb": "low",
                 "tmbScore": 0.73,
+                "nhcOrganism": "HHV-4",
+                "nhcReadsPerMil": 14.0,
+                "nhcStatus": "unknown",
             }
         ]
     }
@@ -165,6 +197,7 @@ def test_yml_with_date_namespace():
     xml = read_xml(f"{BASE_PATH}/data/sample_namespace.xml")
 
     yml = get_test_yml(
+        xml["rr:ResultsReport"]["rr:CustomerInformation"],
         xml["rr:ResultsReport"]["rr:ResultsPayload"],
         "SA-1612348",
         f"{BASE_PATH}/data",
@@ -181,9 +214,17 @@ def test_yml_with_date_namespace():
                 "sourceFile": "SA-1612348.xml",
                 "testType": "FoundationOne Heme",
                 "indexedDate": "2016-07-15",
+                "receivedDate": "2016-07-21",
+                "collDate": "2016-07-15",
+                "reportDate": "2016-08-25",
                 "mrn": "12345678",
+                "reportID": "SMP37669",
                 "patientDOB": "2002-12-12",
                 "patientLastName": "Patient",
+                "medFacilName": "ABC Oncology",
+                "medFacilID": "200313",
+                "orderingMDName": "Smith, John",
+                "orderingMDNPI": "1508888051",
                 "bodySite": "Bone",
                 "bodySiteSystem": "http://foundation.com/bodySite",
                 "bodySiteDisplay": "Bone",
@@ -312,6 +353,7 @@ def test_yml_with_missing_mrn():
     xml = read_xml(f"{BASE_PATH}/data/sample_missing_mrn.xml")
 
     yml = get_test_yml(
+        xml["rr:ResultsReport"]["rr:CustomerInformation"],
         xml["rr:ResultsReport"]["rr:ResultsPayload"],
         "SA-1612348",
         f"{BASE_PATH}/data",
@@ -328,9 +370,17 @@ def test_yml_with_missing_mrn():
                 "sourceFile": "SA-1612348.xml",
                 "testType": "FoundationOne Heme",
                 "indexedDate": "2016-07-15",
+                "receivedDate": "2016-07-21",
+                "collDate": "2016-07-15",
+                "reportDate": "2016-08-25",
                 "mrn": "",
+                "reportID": "SMP37669",
                 "patientDOB": "2002-12-12",
                 "patientLastName": "Patient",
+                "medFacilName": "ABC Oncology",
+                "medFacilID": "200313",
+                "orderingMDName": "Smith, John",
+                "orderingMDNPI": "1508888051",
                 "bodySite": "Bone",
                 "bodySiteSystem": "http://foundation.com/bodySite",
                 "bodySiteDisplay": "Bone",
@@ -377,6 +427,7 @@ def test_yml_with_no_biomarkers():
     xml = read_xml(f"{BASE_PATH}/data/sample_no_biomarkers.xml")
 
     yml = get_test_yml(
+        xml["rr:ResultsReport"]["rr:CustomerInformation"],
         xml["rr:ResultsReport"]["rr:ResultsPayload"],
         "SA-1612348",
         f"{BASE_PATH}/data",
@@ -394,9 +445,17 @@ def test_yml_with_no_biomarkers():
                 "sourceFile": "SA-1612348.xml",
                 "testType": "FoundationOne Heme",
                 "indexedDate": "2016-07-15",
+                "receivedDate": "2016-07-21",
+                "collDate": "2016-07-15",
+                "reportDate": "2016-08-25",
                 "mrn": "12345999",
+                "reportID": "SMP37779",
                 "patientDOB": "2002-04-12",
                 "patientLastName": "Patient",
+                "medFacilName": "ABC Oncology",
+                "medFacilID": "200313",
+                "orderingMDName": "Smith, John",
+                "orderingMDNPI": "1508888051",
                 "bodySite": "Bone",
                 "bodySiteSystem": "http://foundation.com/bodySite",
                 "bodySiteDisplay": "Bone",
@@ -440,9 +499,131 @@ def test_yml_with_no_biomarkers():
     }
 
 
+def test_yml_with_multiple_non_human_content():
+    cleanup()
+    os.makedirs(f"{BASE_PATH}/data/SA-1612348", exist_ok=True)
+
+    xml = read_xml(f"{BASE_PATH}/data/sample_with_multiple_non_human_content.xml")
+
+    yml = get_test_yml(
+        xml["rr:ResultsReport"]["rr:CustomerInformation"],
+        xml["rr:ResultsReport"]["rr:ResultsPayload"],
+        "SA-1612348",
+        f"{BASE_PATH}/data",
+        None,
+        True,
+        ".lifeomic/foundation",
+    )
+
+    assert yml == {
+        "tests": [
+            {
+                "name": "Foundation Medicine",
+                "reference": "GRCh37",
+                "sourceFile": "SA-1612348.xml",
+                "testType": "FoundationOne Heme",
+                "indexedDate": "2016-07-15",
+                "receivedDate": "2016-07-21",
+                "collDate": "2016-07-15",
+                "reportDate": "2016-08-25",
+                "mrn": "12345678",
+                "reportID": "SMP37669",
+                "patientDOB": "2002-12-12",
+                "patientLastName": "Patient",
+                "medFacilName": "ABC Oncology",
+                "medFacilID": "200313",
+                "orderingMDName": "Smith, John",
+                "orderingMDNPI": "1508888051",
+                "bodySite": "Bone",
+                "bodySiteSystem": "http://foundation.com/bodySite",
+                "bodySiteDisplay": "Bone",
+                "diagnosis": "PEDIATRIC Bone osteosarcoma",
+                "diagnosisDisplay": "PEDIATRIC Bone osteosarcoma",
+                "diagnosisSystem": "http://foundation.com/diagnosis",
+                "files": [
+                    {
+                        "type": "copyNumberVariant",
+                        "sequenceType": "somatic",
+                        "fileName": ".lifeomic/foundation/SA-1612348/SA-1612348.copynumber.csv",
+                    },
+                    {
+                        "type": "structuralVariant",
+                        "sequenceType": "somatic",
+                        "fileName": ".lifeomic/foundation/SA-1612348/SA-1612348.structural.csv",
+                    },
+                    {
+                        "type": "shortVariant",
+                        "sequenceType": "somatic",
+                        "fileName": ".lifeomic/foundation/SA-1612348/SA-1612348.nrm.vcf.gz",
+                    },
+                ],
+                "patientInfo": {
+                    "firstName": "Test",
+                    "lastName": "Patient",
+                    "gender": "male",
+                    "dob": "2002-12-12",
+                    "identifiers": [
+                        {
+                            "codingSystem": "http://hl7.org/fhir/v2/0203",
+                            "codingCode": "MR",
+                            "value": "12345678",
+                        }
+                    ],
+                },
+                "lossOfHeterozygosityScore": 21.1,
+                "lossOfHeterozygosityStatus": "high",
+                "msi": "stable",
+                "tmb": "low",
+                "tmbScore": 0.73,
+                "nhcOrganism": ["HHV-4", "HPV-18", "HHV-4"],
+                "nhcReadsPerMil": [14.0, 17.0, 92.0],
+                "nhcStatus": ["unknown", "unknown", "unknown"],
+            }
+        ]
+    }
+
+
 def test_get_mrn():
     missing_mrn_result = get_mrn({"LastName": "Baggins"})
     assert missing_mrn_result == ""
 
     existing_mrn_result = get_mrn({"LastName": "Baggins", "MRN": "mrn_001"})
     assert existing_mrn_result == "mrn_001"
+
+
+def test_get_trf():
+    missing_trf = get_trf({"LastName": "Baggins"})
+    assert missing_trf == ""
+
+    existing_trf = get_trf({"LastName": "Baggins", "TRFNumber": "SMP102938"})
+    assert existing_trf == "SMP102938"
+
+
+def test_get_med_facil():
+    missing_med_facil_ID = get_med_facil({"MedFacilName": "ABC Oncology", "MedFacilID": ""})
+    assert missing_med_facil_ID == ["ABC Oncology", ""]
+
+    missing_med_facil_name = get_med_facil({"MedFacilName": "", "MedFacilID": "200313"})
+    assert missing_med_facil_name == ["", "200313"]
+
+    missing_med_facil_both = get_med_facil({"MedFacilName": "", "MedFacilID": ""})
+    assert missing_med_facil_both == ["", ""]
+
+    existing_med_facil_both = get_med_facil(
+        {"MedFacilName": "ABC Oncology", "MedFacilID": "200313"}
+    )
+    assert existing_med_facil_both == ["ABC Oncology", "200313"]
+
+
+def test_get_ordering_md():
+    missing_md_NPI = get_ordering_md({"OrderingMD": "Smith, John"}, "")
+    assert missing_md_NPI == ["Smith, John", ""]
+
+    missing_md_name = get_ordering_md({"OrderingMD": ""}, "9706")
+    assert missing_md_name == ["", "9706"]
+
+    missing_md_both = get_ordering_md({"OrderingMD": ""}, "")
+    assert missing_md_both == ["", ""]
+
+    existing_md_both = get_ordering_md({"OrderingMD": "Smith, John"}, "9706")
+    assert existing_md_both == ["Smith, John", "9706"]
